// Requests a new question from the server.
function AskQuestion() {
  fetch("/new").then((val) => {
    if (val.status === 200) {
      return val.json();
    } else {
      ShowError(`Server Error: ${val.statusText}`);
    }
  }).then((val) => {
    if (val.index !== undefined && val.text !== undefined) {
      HandleQuestion(val.index, val.text);
    } else {
      console.log(val);  // for debugging
      ShowError('server response missing "index" or "text"');
    }
  });
}

let index = -1;  // store the index of the most recently received question

// Shows the question on the page.
function HandleQuestion(newIndex, newText) {
  index = newIndex;

  const aelem = document.getElementById("answer");
  aelem.innerHTML = "";  // erase the last answer

  const eelem = document.getElementById("error");
  eelem.innerHTML = "";  // erase any old error message

  const qelem = document.getElementById("question");
  qelem.innerHTML = [    // show the new question
      '<div>',
        '<label htmlFor="answer">Question</label>',
        '<span id="q-text"></span>',
      '</div>',
      '<div>',
        '<label htmlFor="answer">Answer</label>',
        '<input type="text" id="user-answer" name="answer"></input>',
      '</div>',
      '<div style="margin-top: 15px;">',
        '<button type="button" onclick="CheckAnswer(event);">Submit</button>',
      '</div>',
    ].join("\n");
  document.getElementById("q-text").innerText = newText;  // extra safe
}

// Requests an answer-check from the server.
function CheckAnswer(evt) {
  evt.preventDefault();

  const answer = document.getElementById("user-answer").value;
  if (answer.trim().length === 0)
    return;  // nothing entered; ignore

  const url = "/check?index=" + encodeURIComponent(index) +
      "&answer=" + encodeURIComponent(answer);
  fetch(url).then((val) => {
    if (val.status === 200) {
      return val.json();
    } else {
      ShowError(`Server Error: ${val.statusText}`);
    }
  }).then((val) => {
    if (val.correct !== undefined) {
      HandleAnswer(val.correct);
    } else {
      console.log(val);  // for debugging
      ShowError('server response missing "correct"');
    }
  });
}

function HandleAnswer(correct) {
  const eelem = document.getElementById("error");
  eelem.innerHTML = "";  // erase any old error message

  const aelem = document.getElementById("answer");
  if (correct) {
    aelem.innerHTML = '<p><b>Congratulations!</b> You are correct.</p>';
  } else {
    aelem.innerHTML = '<p>Sorry, your answer was incorrect.</p>';
  }
}

// Shows an error message on the page.
function ShowError(text) {
  const eelem = document.getElementById("error");
  eelem.innerHTML = "<p><b>Error:</b> " + text + "</p>";
}
